@@ -5,15 +5,17 @@ from pydantic import BaseModel, Field
 from datetime import datetime
 
 
-class DetaModel(BaseModel):
+class DetaModelMetaclass(type):
+    def __new__(cls, clsname, bases, attrs, db_name: Optional[str] = None):
+        attrs['__base_name__'] = attrs.get('__base_name__', db_name)
+        return super(DetaModelMetaclass, cls).__new__(cls, clsname, bases, attrs)
+
+
+class DetaModel(BaseModel, metaclass=DetaModelMetaclass):
     key: Optional[str] = None
 
     _project_key: Optional[str] = None
 
-    def __init_subclass__(cls, db_name: Optional[str] = None):
-        super(DetaModel, cls).__init_subclass__()
-        if not hasattr(cls, '__base_name__'):
-            cls.__base_name__ = db_name
 
     @classmethod
     def set_project_key(cls, project_key: str):
